pub enum BlockWeightMode<T: Config> {
FullCore {
context: BlockNumberFor<T>,
},
PotentialFullCore {
context: BlockNumberFor<T>,
first_transaction_index: Option<u32>,
target_weight: Weight,
},
FractionOfCore {
context: BlockNumberFor<T>,
first_transaction_index: Option<u32>,
},
}Expand description
The current block weight mode.
Based on this mode MaxParachainBlockWeight determines the current allowed block weight.
Variants
FullCore
The block is allowed to use the weight of a full core.
Fields
context: BlockNumberFor<T>The block in which this mode was set. Is used to determine if this is maybe stale mode
setting, e.g. when running validate_block.
PotentialFullCore
The current active transaction is allowed to use the weight of a full core.
Fields
context: BlockNumberFor<T>The block in which this mode was set. Is used to determine if this is maybe stale mode
setting, e.g. when running validate_block.
first_transaction_index: Option<u32>The index of the first transaction.
Stays None for all inherents until there is the first transaction.
target_weight: WeightThe target weight that was used to determine that the extrinsic is above this limit.
FractionOfCore
The block is only allowed to consume its fraction of the core.
How much each block is allowed to consume, depends on the target number of blocks and the available cores on the relay chain.
Fields
context: BlockNumberFor<T>The block in which this mode was set. Is used to determine if this is maybe stale mode
setting, e.g. when running validate_block.